@@ -35,24 +35,19 @@ class Data:
         title = dataname + " | " + str(datatype)
         logger.info("=" * 12 + " " + title + " " + "=" * 12)
         if datatype in ("xls", "xlsx"):
-            self.data = pd.read_excel(
-                os.path.join(conf.get("PROJ_DIR"), dataname)
-            )
+            self.data = pd.read_excel(os.path.join(conf.get("PROJ_DIR"), dataname))
         elif datatype in ("csv", "txt"):
-            self.data = pd.read_csv(
-                os.path.join(conf.get("PROJ_DIR"), dataname)
-            )
+            self.data = pd.read_csv(os.path.join(conf.get("PROJ_DIR"), dataname))
         elif datatype in ("api",):
-            api_cls = importlib.import_module(
-                "services." + dataname, package=".."
-            )
+            api_cls = importlib.import_module("services." + dataname, package="..")
             api = api_cls.Api()
             self.data = api.data
+        elif datatype in ("json"):
+            self.data = pd.read_json(os.path.join(conf.get("PROJ_DIR"), dataname))
         else:
             # read sql file from ./sqls
             str_sql = open(
-                os.path.join(conf.get("PROJ_DIR"), "sqls", dataname),
-                encoding="utf-8",
+                os.path.join(conf.get("PROJ_DIR"), "sqls", dataname), encoding="utf-8",
             ).read()
             sql = str_sql
             # pre process before sql loaded
@@ -70,9 +65,7 @@ def animate(dataname, log):
     for c in itertools.cycle(["|", "/", "-", "\\"]):
         if getattr(t, "Done", True):
             break
-        sys.stdout.write(
-            "\r<{}> running {} {} ms\r".format(dataname, c, elapsed_time)
-        )
+        sys.stdout.write("\r<{}> running {} {} ms\r".format(dataname, c, elapsed_time))
         sys.stdout.flush()
         time.sleep(0.1)
         elapsed_time += 100
@@ -83,9 +76,7 @@ def animate(dataname, log):
 
 
 def _get_df(sql, datatype, dataname):
-    animate_thread = threading.Thread(
-        target=animate, args=(dataname, logger.info)
-    )
+    animate_thread = threading.Thread(target=animate, args=(dataname, logger.info))
     animate_thread.daemon = True
     animate_thread.Done = False
     animate_thread.start()
